@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "slothbar" "0.30.1"
+(define-package "slothbar" "20251124.353"
   "Emacs X window manager status bar."
   '((all-the-icons "5.0.0")
     (backlight     "1.4")
@@ -14,8 +14,8 @@
     (xelb          "0.18")
     (emacs         "28.1"))
   :url "https://codeberg.org/agnes-li/slothbar"
-  :commit "f8066074a93dd6e2be54c4a5e503df9f78178a3e"
-  :revdesc "v0.30.1-0-gf8066074a93d"
+  :commit "52010da65a4688b2b2f16427f81dfeedf4443077"
+  :revdesc "52010da65a46"
   :keywords '("frames" "hardware")
   :authors '(("Jo Gay" . "jo.gay@mailfence.com")
              ("Agnes Li" . "agnes.li@mailfence.com"))
