@@ -46,6 +46,7 @@
 
 (require 'cl-lib)
 (require 'compat)
+(require 'mule-util)
 (require 'rx)
 (require 'xcb)
 (require 'xcb-ewmh)
@@ -85,7 +86,7 @@ the head of the list."
 
 (cl-defstruct (slothbar-workspaces
                (:include slothbar-module (name "workspaces") (icon ?󰯉)
-                         (format "^f2^2^[^5^f4%i^]%w")
+                         (format "^2^[^5^f4%i^]%w")
                          (format-fn #'slothbar-workspaces-format-format))
                (:constructor slothbar-workspaces-create)
                (:copier nil)))
@@ -95,14 +96,22 @@ the head of the list."
   :type 'boolean
   :group 'slothbar-workspaces)
 
+(defcustom slothbar-workspaces-truncate-to-width 16
+  "A positive integer indicating a limit at which to truncate workspace names."
+  :type 'natnum
+  :group 'slothbar-workspaces)
+
 (defun slothbar-workspaces--format-fn-spec (ws-list)
   "Generate a spec suitable for `format-spec' from data in WS-LIST.
 
 See `slothbar-workspaces-generate-list-fn' for the expected structure of
 WS-LIST."
   (cl-flet ((sanitize (s)
-              (string-replace " " "-"
-               (replace-regexp-in-string "[\\^]" "^^" (string-trim s)))))
+              (truncate-string-to-width
+               (string-replace " " "-"
+                               (replace-regexp-in-string "[\\^]" "^^" (string-trim s)))
+               slothbar-workspaces-truncate-to-width
+               nil nil t)))
     `((?w . ,(cl-loop for (ws status) in ws-list
                       for ws-safe = (sanitize ws)
                       concat
@@ -148,7 +157,7 @@ WS-LIST."
 
 ;;; Begin slothbar-workspaces-generate-list-fn implementations
 
-(declare-function shorten-strings "shorten" (lst &optional tail-count))
+(declare-function shorten-strings "shorten" (lst))
 
 ;;; ewmh (extended window manager hints)
 
